function y=americanputprice_binomial(stock_price,strike,r,sigma,maturity,number_steps)
% AMERICANPUTPRICE_BINOMIAL Binomial American put price
%
% Function estimates the price of an American put, using the binomial approach.
% 
% The arguments are as follows, in order: the stock price, the strike,
% the risk-free rate, the volatility of the underlying, the time to 
% maturity of the option, and the number of time-steps in the
% binomial tree. 
%
% NB: The time to maturity of the option is in days. 
% 
% Revised by Kevin Dowd, November 8th, 2001.
% ****************************************************************
%
% Initialise parameters
%
prob=.5; % Probability of up-move; equal probability approach used
N=number_steps;
maturity=maturity/360; % Convert maturity to units of years
delta_t=maturity/N; % length of incremental steps
u=2*exp(r*delta_t+2*sigma*sqrt(delta_t))/(exp(2*sigma*sqrt(delta_t))+1); % Up-move
d=2*exp(r*delta_t)/(exp(2*sigma*sqrt(delta_t))+1); % Down-move
% Note that these up- and down-moves incorporate risk neutral approach
discount=exp(-r*delta_t); % Discount factor
%
% Stock price tree
%
S(1)=stock_price*(d^N);
for i=2:(N+1) % i is number of up-moves plus 1
   S(i)=S(i-1)*u*u;
  end
%
%  Option price tree
% 
%       Terminal option values
%
for i=1:(N+1)
   x(i)=max(strike-S(i),0);
end
%
%       Option values prior to expiration
%
for j=N:-1:1
    for i=1:j
        x(i)=discount*(prob*x(i+1)+(1-prob)*x(i));
        S(i)=S(i)*u;
        %
        % Check for early exercise
        %
        ExerciseValue=max(0,strike-S(i));
        if ExerciseValue>x(i)
            x(i)=ExerciseValue;
        end
    end
end
%
y=x(1); % Initial option value

