function y=blackscholescallvar_analytic(amount_invested,stock_price,strike,r,mu,volatility,maturity, cl, hp)
% BLACKSCHOLESCALLVAR_ANALYTIC Analytical VaR for Black-Scholes call 
%
% Function derives the VaR of a Black Scholes call position for specified confidence level
% and holding period, using an analytical solution. 
%
% The first argument is the amount invested, the second is the stock price, the third is the 
% strike price, the fourth is the risk-free rate, the fifth is the mean return, the sixth is volatility,  
% the seventh is the term to maturity, the eighth is the confidence level and the last is 
% the holding period. Rates are expressed in annualised terms and periods in days.
% 
% Amount invested is positive (negative) if option position is long (short).
%
% NB: cl and hp are scalars.
%
% Reference: John Hull, "Options, futures, and other derivatives," 4th edition
% Upper Saddle River, NJ: Prentice Hall, 2000, chapter 11. 
%
% Revised by Kevin Dowd, November 6th, 2001.
% *****************************************************************************************
%
% Derivation of number of options from amount invested
%
option_price_now=blackscholescallprice(stock_price,strike, r, volatility, maturity);
number=abs(amount_invested)/option_price_now;
%
% For long option position
%
if amount_invested>0
    %
    % Critical stock price derived from lognormal asset price process; see Hull, p. 238
    %
    log_s_star=norminv(1-cl,log(stock_price)+(mu-(volatility^2)/2)*hp/360,volatility*sqrt(hp/360));
    s_star=exp(log_s_star);
    %
    % VaR
    %
   option_price_future=blackscholescallprice(s_star,strike, r, volatility, maturity-hp);
   var=number*(option_price_now-option_price_future);
end
% 
% For short option position 
%
if amount_invested<0
    %
    % Critical stock price
    %
    log_s_star=norminv(cl,log(stock_price)+(mu-(volatility^2)/2)*hp/360,volatility*sqrt(hp/360));
    s_star=exp(log_s_star);
    %
    % VaR
    %
  option_price_future=blackscholescallprice(s_star,strike, r, volatility, maturity-hp);
  var=-number*(option_price_now-option_price_future);
end
y=var;