function y=blackscholescallvar_sim(amount_invested,stock_price,strike,r,mu,sigma,maturity,M,cl,hp)
% BLACKSCHOLESCALLVAR_SIM VaR of Black-Scholes call position estimated by Monte Carlo simulation
%
% Function estimates the VaR of a Black-Scholes call option position 
% using Monte Carlo simulation.
%
% The arguments are: the amount invested, the current stock price, the strike 
% price, the risk-free rate, the expected rate of return on the underlying asset,
% the stock volatility, the term to maturity, the number of iterations in the 
% Monte Carlo simulation exercise, the VaR confidence level and the VaR holding
% period. 
%
% The returns and volatility are in annualised terms, and the maturity and holding]
% period are in days. The amount invested is positive (negative) if the option 
% position is long (short).
%
% NB: cl and hp are scalars.
%
% Revised by Kevin Dowd, July 16th, 2001.
% ****************************************************************************
tic % Start timer
%
% Precompute constants
%
annual_maturity=maturity/360; % Annualised maturity
annual_hp=hp/360; % Annualised holding period
N=1; % Number of steps - only one needed for BS option
dt=annual_hp/N; % Size of time-increment equal to holding period
nudt=(mu-0.5*sigma^2)*dt;
sigmadt=sigma*sqrt(dt);
lnS=log(stock_price);
initial_option_price=blackscholescallprice(stock_price,strike,r,sigma,maturity);
number_of_options=abs(amount_invested)/initial_option_price;
%
% Stock price simulation process
%
n=100:200;
z=normrnd(0,1,M,1);
for n=100:M
    for i=1:n
        lnSt(i)=lnS+nudt+sigmadt*z(i); % Random stock price movement
        new_stock_price(i)=exp(lnSt(i)); % New stock price
        Profit_or_loss(i)=(blackscholescallprice(new_stock_price(i),strike,r,sigma,...
            maturity-hp)-initial_option_price)*number_of_options;
    end
var(n)=hsvar(Profit_or_loss,cl);
end
var(1:100)=[];
n=101:M;
% [n var]
plot(n,var)
%
toc % End timer