function bondvaretl(amount_invested,couponrate,mu,sigma,...
    reversion_parameter,spotrate,settle,maturity,...
    number_trials,number_steps,cl)
% BONDVARETL Estimates the VaR and ETL of a coupon paying bond using
% Monte Carlo simulation, as illustrated in Box 6.1.
%
% The arguments are as follows: the amounte invested, the coupon
% rate, the mean and volatility of the interest rate, the interest-
% rate mean reversion parameter, the spot rate, the settlement 
% date, the maturity of the bond, the number of simulation 
% trials, and the VaR confidence level.
%
% For further information on settlement and maturity see the 
% Financial Derivatives Toolbox help section. 
% 
% The calculations assume that the holding period is a year and
% that the interim coupon payments are reinvested at going 
% spot rate. 
%
% Revised by Kevin Dowd, November 8th, 2001.
% ***********************************************************
tic
%
% Initial settings
%
M=number_trials;
N=number_steps;
k=reversion_parameter;
hp=360;; % Holding period set to 1 year for convenience
dt=hp/(360*N); 
% 
% Initial bond pricing and determination of number of bonds in position
%
InstSet=instadd('Bond',couponrate,settle,maturity);
RateSpec=intenvset('Rates', spotrate, 'StartDates','01-Jan-2003', 'EndDates', '01-Jan-2008');
initial_bond_price=intenvprice(RateSpec,InstSet);
number_bonds=amount_invested/initial_bond_price;
% 
% Spot rate model (CIR)
% 
for i=1:M
    for j=1:1
        r(i,j)=spotrate;
    end
end
for i=1:M
    for j=2:N
        r(i,j)=(1-k*dt)*r(i,j-1)+k*mu*dt+sigma*sqrt(r(i,j-1)*dt)*normrnd(0,1);    
    end
    midterm_r(i)=r(i,N/2); % Mid-year interest rate
    terminal_r(i)=r(i,N); % Terminal r
end
%
% Terminal bond price
%
NewSettle='01-Jan-2004';
for i=1:M
    NewInstSet=instadd('Bond',couponrate,newsettle,maturity);
    NewRateSpec(i)=intenvset('Rates',terminal_r(i), 'StartDates',...
        '01-Jan-2004', 'EndDates', '01-Jan-2008');
    terminal_bond_price(i)=intenvprice(NewRateSpec(i),NewInstSet);
    Profit_or_loss(i)=No_bonds*(terminal_bond_price(i)-initial_bond_price+...
        (couponrate/2)*(1+midterm_r(i)/2)+couponrate/2);
    % P/L takes account of coupon payments
end
%
% VaR and ETL
% 
var=hsvar(Profit_or_loss,cl)
etl=hsetl(Profit_or_loss,cl)
toc