function y=frechetvarplot2D_hp(mu, sigma, tail_index,cl,hp)
% FRECHETVARPLOT2D_HP Plots Frechet VaR against holding period 
%
% Function plots the VaR of a portfolio against holding period, assuming losses are Frechet distributed,
% for given confidence level and range of holding periods.
% 
% Note that the long-right-hand tail is fitted to losses, not profits. 
% 
% There are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the tail index, the 
% fourth is the VaR confidence level, and the fifth is the VaR holding period. 
% 
% cl must be a scalar, and hp must be a vector.
%
% Source: P. Embrechts, C. Kluppelberg and T. Mikosch, Modelling Extremal Events
% for Insurance and Finance. Berlin: Springer, 1997, p. 324.
%
% Revised by Kevin Dowd, November 11th, 2001.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[tail_index_row,tail_index_col]=size(tail_index);
if max(tail_index_row,tail_index_col)>1
    error('Tail index must be a scalar');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a vector');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
% 
% To check that hp is read as a row vector  as required
% 
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that parameters obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if min(tail_index)<=0
    error('Tail index must be greater than 0');
end
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% Derivation of location and scale parameters
%
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
%
% VaR estimation
%
var=frechetvar(mu,sigma,tail_index,cl,hp);             
%
% Plotting
%
plot(hp,var);
axis;
cl_percent=100*cl;
%
% Input data labels
%
text(min(cl)+.1*(max(hp)-min(hp)),max(var)-.1*(max(var)-min(var)),'Input parameters','Fontweight','bold')
text(min(cl)+.1*(max(hp)-min(hp)),max(var)-.2*(max(var)-min(var)),['Daily mean L/P = ',num2str(-mu)])
text(min(cl)+.1*(max(hp)-min(hp)),max(var)-.3*(max(var)-min(var)),['St. dev. of daily L/P = ',num2str(sigma)])
text(min(cl)+.1*(max(hp)-min(hp)),max(var)-.4*(max(var)-min(var)),['Tail index = ',num2str(tail_index)])
text(min(cl)+.1*(max(hp)-min(hp)),max(var)-.5*(max(var)-min(var)),['Confidence level = ',num2str(cl_percent),'%'])
%
% Axis labels
%
xlabel('Holding period','Fontweight','bold');
ylabel('VaR','rotation',0,'horizontal','right','Fontweight','bold');
title(['Frechet VaR against holding period'],'FontSize',12,'Fontweight','bold')


