function y=gumbeletlplot2D_hp(varargin)
% GUMBELETLPLOT2D_HP Plots normal VaR against holding period
%
% Function plots the ETL of a portfolio against holding period, assuming L/P is Gumbel distributed,
% for specified confidence level.
% 
% Note that the long-right-hand tail is fitted to losses, not profits. 
%
% If there are three arguments, the first argument is a vector of daily P/L data, the second
% is the VaR confidence level, and the third is the VaR holding period in days. 
% 
% If there are four arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the VaR confidence 
% level, and the fourth is the VaR holding period. 
% 
% hp must be a row vector, and cl must be a scalar.
%
% Revised by Kevin Dowd, June 24th, 2000
% *****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>4,
    error('Too many arguments');
end
if nargin ==4
    mu=varargin{1};
    sigma=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
if nargin==3
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    cl=varargin{2};
    hp=varargin{3};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a vector');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
% 
% To check that hp is read as a row vector  as required
%
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level must be greater than 0');
end
if min(hp)<=0
    error('Holding periods must be greater than 0');
end
%
% Derivation of location and scale parameters
%
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
%
% VaR estimation
%
var=location*ones(size(cl))-scale*log(log(cl.^-1));     % Gumbel VaR  
%
% ETL estimation
%
n=1000;                               % Number of slices into which tail is divided 
cl0=cl;                                % Initial confidence level
v=var;                                                
delta_cl=(1-cl)/n;         % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                     % Revised cl
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
v=v+location*ones(size(cl))-scale*log(log(cl.^-1)); 
end;
etl=v/n;                                             % ETL
%
plot(hp,etl);
axis;
cl_label=100*cl0;
%
% Input data labels
%
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.1*(max(etl)-min(etl)),'Input parameters','Fontweight','bold')
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.2*(max(etl)-min(etl)),['Daily mean L/P = ',num2str(-mu)])
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.3*(max(etl)-min(etl)),['St. dev. of daily L/P = ',num2str(sigma)])
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.4*(max(etl)-min(etl)),['Confidence level = ',num2str(cl_label),'%'])
%
% Axis labels
%
xlabel('Holding period','Fontweight','bold');
ylabel('ETL','rotation',0,'horizontal','right','Fontweight','bold');
title('Gumbel ETL against holding period','FontSize',12,'Fontweight','bold');