function y=gumbelvarfigure(varargin)
% % GUMBELVARFIGURE Figure of Gumbel VaR and pdf of L/P
% 
% Function gives figure showing the VaR and pdf of a portfolio assuming L/P is Gumbel distributed,
% for specified confidence level and holding period.
%
% Note that the long-right-hand tail is fitted to losses, not profits. 
% 
% If there are three arguments, the first argument is a vector of daily P/L data, the second
% is the VaR confidence level, and the third is the VaR holding period in days. 
% 
% If there are four arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the VaR confidence 
% level, and the fourth is the VaR holding period. 
% 
% Note: Both cl and hp should be entered as scalars.
% 
% Source: M. Evans, N. Hastings, and B. Peacock "Statistical Distribtions", 3rd edition, New York:
% John Wiley, 2000, p. 85.
%
% Revised by Kevin Dowd, June 24th, 2001.
%*****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>4,
    error('Too many arguments');
end
if nargin ==4
    mu=varargin{1};
    sigma=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
if nargin==3
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    cl=varargin{2};
    hp=varargin{3};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar ');
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% Derivation of location and scale parameters
%
scale=sigma*sqrt(6)*sqrt(hp')/pi;
location=-mu*hp'-scale*.57722;
%
% VaR estimation
%
var=location*ones(size(cl))-scale*log(log(cl.^-1));  % Gumbel VaR  
%                          
% Plotting
%
x_min=-mu-5*sigma;
x_max=-mu+5*sigma;
delta=(x_max-x_min)/100;
x=x_min:delta:x_max;
p=(1/scale).*exp(-(x-location)/scale).*exp(-exp(-(x-location)/scale));
plot(x,p); 
r=[x_min,x_max,0,max(p)*1.1];
axis(r);
hold on;
u=[var,var]; 
v=[0,.6*max(p)];
line=plot(u,v, 'Color','black');
cl_for_label=100*cl;
text(-mu-4.5*sigma,.95*max(p),'Input parameters','Fontweight','bold')
text(-mu-4.5*sigma, .875*max(p),['Daily mean L/P = ',num2str(-mu)])
text(-mu-4.5*sigma, .8*max(p),['St. dev. of daily L/P = ',num2str(sigma)])
text(-mu-4.5*sigma, .725*max(p),['Holding period = ',num2str(hp),' day(s)'])
text(var,.7*max(p),['VaR at ',num2str(cl_for_label),'% CL'],'Fontweight','bold','horizontal','center')
text(var,.64*max(p),['= ',num2str(var)],'Fontweight','bold','horizontal','center')
xlabel('Loss (+) / Profit (-)','horizontal','left','Fontweight','bold');
ylabel('Probability','rotation',90,'horizontal','center','Fontweight','bold');
title(['Gumbel VaR'],'FontSize',12,'Fontweight','bold');
hold off