function y=lognormalvar(varargin)
% LOGNORMALVAR VaR for normally distributed geometric returns
%
% Function estimates the VaR of a portfolio assuming that geometric 
% returns are normally distributed, for specified confidence level 
% and holding period.
% 
% If there are four arguments, the first argument is a vector of daily
% geometric return data, the second is the size of the investment, the 
% third is the VaR confidence level, and the fourth is the VaR holding
% period in days. 
% 
% If there are five arguments, the first is the assumed daily mean geometric 
% return, the second is the assumed standard deviation of daily geometric 
% returns, the third is the size of the investment, the fourth is the 
% VaR confidence level, and the fifth is the VaR holding period. 
% 
% If cl and hp are both scalars, function gives a scalar answer.
% If cl is a vector, and hp is a scalar, function gives a row vector of VaRs.
% If cl is a scalar and hp is a vector, function  gives a column vector of VaRs.
% If cl and hp are both vectors, function gives a matrix of VaRs with cl read 
% across rows and hp down columns.
%
% Note: Position is assumed to be long. 
%
% Revised by Kevin Dowd, June 2, 2001.
% *****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that 
% arguments are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin==5
    mu=varargin{1};
    sigma=varargin{2};
    investment=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    investment=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector  as required
% And to check that hp is read as a scalar or column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% VaR estimation
%
y=investment-exp(sigma*sqrt(hp')*norminv(1-cl,0,1)+mu*hp'*ones(size(cl))...
    +log(investment)); %VaR 
