function y=modifiednormalCDbacktest(PandL)
% MODIFIEDNORMALCDBACKTEST Modified Crnkovic-Drachman backtest for normal P/L 
%
% Function carries out a modified Crnkovic-Drachman backtest 
% for a VaR risk measurement model, assuming P/L is normally distributed,
% for specified VaR confidence level.
% 
% Note that this test differs from the real Crnkovic-Drachman test in two 
% regards: (1)It only deals with the first stage of their test procedure, and 
% does not address the second stage, which is a BDS test of normality. 
% (2) It uses the Kolmogorov-Smirnov distance test, rather than the 
% Kuiper test they used. This is more convenient given Matlab's 'kstest' 
% procedure.
%
% The first argument is a vector of portfolio P/L observations, the second 
% is a corresponding matrix of P/L percentile forecasts.
%
% Reference: Cedomir Crnkovic and Jordan Drachman, "Quality Control", Risk, 
% Vol. 9, No. 9, September 1996, pp. 139-143.
%
% Revised by Kevin Dowd, June 24th, 2001.
% *****************************************************************************************
%
% Identify parameters and VaR
%
mu=mean(PandL) % Mean P/L
sigma=std(PandL) % Standard deviation of P/L
cl=.00001 % Take extremely small VaR confidence level
VaR=normalvar(PandL,cl,1) % 
n=length(PandL); % Number of obsevations
%
% Determine tail losses
%
index=find(-PandL>VaR);
t=length(index); % Number of tail losses
%
LandP=-PandL; % Construct L/P series
LandP=sort(LandP); % Sorts losses into order
tail_losses=LandP(LandP>VaR); % Derives tail losses
% 
% Calculate empirical cdf for plot
% 
empirical_cdf=cdfcalc(LandP);
empirical_cdf=empirical_cdf(empirical_cdf>0);
%
% Calculate predicted cdf
%
for i=1:1
  predicted_cdf(i)=0;
end
for i=2:n
  predicted_cdf(i)=normcdf(LandP(i),-mu,sigma); % Normal CDF
end
predicted_cdf=predicted_cdf';
%
% Plotting
%
plot(LandP,empirical_cdf,LandP,predicted_cdf)
axis([VaR max(tail_losses) cl 1]);
xlabel('Losses/Profits','Fontweight','bold');
ylabel('Cumulative probability','Fontweight','bold');
title(['Predicted and Empirical Losses'],'FontSize',12,'Fontweight','bold');
whitebg;
%
% Derive cdf for predicted tail observations
%
predicted_cdf=predicted_cdf(LandP>VaR);
for i=1:1
    adj_pred_cdf(i)=(predicted_cdf(i)-cl)/(1-cl);
end
for i=2:t
    adj_pred_cdf(i)=(predicted_cdf(i)-predicted_cdf(i-1))/(1-cl)+...
        adj_pred_cdf(i-1);
end
% 
CDF=[tail_losses adj_pred_cdf'];
%
% Show total PandL, total tail losses, and effective sample size
%
Number_of_observations=n % This gives number of observations
Number_of_excess_losses=t % This gives number of excess losses
Ne=(t^2)/(2*t); % Ne is effective number of data points
Effective_sample_size=Ne
%
% Kolmogorov-Smirnov test statistics and probabilities
% 
%    Three alternative KS approaches, depending on alternative hypothesis
%
[H Prob KSstat]=kstest(tail_losses,CDF,0.05,0); 
KSstat
% Refers to 2-sided alternative hypothesis in which empirical and predicted cdfs differ
% This is set up as the default. COMMENT: INSERT % TWO LINES EARLIER TO DEACTIVATE
%
% [H Prob]=kstest(tail_losses,CDF,0.05,1); COMMENT: DELETE % TO ACTIVATE
% Refers to 1-sided alternative hypothesis in which empirical cdf exceeeds predicted
% cdf
% Alternative hypothesis is that tail losses are less than predicted
%
% [H Prob]=kstest(tail_losses,CDF,0.05,-1); COMMENT: DELETE % TO ACTIVATE
% Refers to 1-sided alternative hypothesis in which empirical cdf is less than
% predicted cdf
% Alternative hypothesis is that tail losses are greater than predicted
%
% Probability that null hypothesis is true, given alternative
%
Prob_of_null_hypothesis=Prob
