function y=normaletlfigure(varargin)
%  NORMALETLFIGURE  Figure of normal VaR and ETL and pdf of L/P
% 
% Function gives figure showing the VaR and ETL and pdf of L/P of a portfolio assuming P/L is normally distributed,
% for specified confidence level and holding period.
% 
% If there are three arguments, the first argument is a vector of daily P/L data, the second
% is the VaR confidence level, and the third is the VaR holding period in days. 
% 
% If there are four arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the VaR confidence 
% level, and the fourth is the VaR holding period. 
% 
% Note: Both cl and hp should be entered as scalars.
%
% Revised by Kevin Dowd, November 4th, 2001.
%*****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>4,
    error('Too many arguments');
end
if nargin ==4
    mu=varargin{1};
    sigma=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
if nargin==3
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    cl=varargin{2};
    hp=varargin{3};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector  as required
% And to check that hp is read as a scalar or column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% Message to indicate how matrix of results is to be interpreted,
% if cl and hp both vary and results are given in matrix form
% 
if max(cl_row,cl_col)>1&max(hp_row,hp_col)>1
    disp('VaR results with confidence level varying across row and holding period down column')
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*norminv(1-cl,0,1)-mu*hp'*ones(size(cl)); %VaR 
%
% Estimate ETL
%
etl=normaletl(mu,sigma,cl,hp);                                 % ETL
%
% Set up figure
%
x_min=-mu-5*sigma;
x_max=-mu+5*sigma;
delta=(x_max-x_min)/100;
x=x_min:delta:x_max;
p=normpdf(x,-mu,sigma);
plot(x,p); 
r=[x_min,x_max,0,max(p)*1.1];
axis(r);
hold on;
%
% Insert line showing VaR
%
u=[var,var]; 
v=[0,.6*max(p)];
line=plot(u,v, 'Color','black');
%
% Insert line showing ETL
%
w=[etl,etl];
z=[0,.45*max(p)];
line=plot(w,z,'Color','black');
%
% Input data labels
%
cl_for_label=100*cl;
text(-mu-4.5*sigma,.95*max(p),'Input parameters','Fontweight','bold')
text(-mu-4.5*sigma, .875*max(p),['Daily mean L/P = ',num2str(-mu)])
text(-mu-4.5*sigma, .8*max(p),['St. dev. of daily L/P = ',num2str(sigma)])
text(-mu-4.5*sigma, .725*max(p),['Holding period = ',num2str(hp),' day(s)'])
%
% VaR line label
%
text(var,.7*max(p),['VaR at ',num2str(cl_for_label),'% CL'],'Fontweight','bold','horizontal','left')
text(var,.65*max(p),['= ',num2str(var)],'Fontweight','bold','horizontal','left')
%
% ETL line label
%
text(etl,.55*max(p),['ETL ='],'Fontweight','bold','horizontal','left')
text(etl,.5*max(p),[num2str(etl)],'Fontweight','bold','horizontal','left')
%
% Labelling of axes
%
xlabel('Loss (+) / Profit (-)','horizontal','left','Fontweight','bold');
ylabel('Probability','rotation',90,'horizontal','center','Fontweight','bold');
title(['Normal VaR and ETL'],'FontSize',12,'Fontweight','bold');
hold off;