function y=normaletlplot2D_hp(varargin)
% NORMALETLPLOT2D_HP Plots normal VaR against holding period
%
% Function plots the ETL of a portfolio against holding period, assuming P/L is normally distributed,
% for specified confidence level.
% 
% If there are three arguments, the first argument is a vector of daily P/L data, the second
% is the VaR confidence level, and the third is the VaR holding period in days. 
% 
% If there are four arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the VaR confidence 
% level, and the fourth is the VaR holding period. 
% 
% hp must be a row vector, and cl must be a scalar.
%
% Revised by Kevin Dowd, November 4th, 2001.
% *****************************************************************************************
% 
% Determine if there are three or four arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>4,
    error('Too many arguments');
end
if nargin ==4
    mu=varargin{1};
    sigma=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
if nargin==3
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    cl=varargin{2};
    hp=varargin{3};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a vector');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
% 
% To check that hp is read as a row vector  as required
%
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level must be greater than 0');
end
if min(hp)<=0
    error('Holding periods must be greater than 0');
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*norminv(1-cl,0,1)-mu*hp'*ones(size(cl)); %VaR 
%
% ETL estimation
%
etl=normaletl(mu,sigma, cl, hp);
%
plot(hp,etl);
axis;
cl_label=100*cl;
%
% Input data labels
%
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.1*(max(etl)-min(etl)),'Input parameters','Fontweight','bold')
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.2*(max(etl)-min(etl)),['Daily mean L/P = ',num2str(-mu)])
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.3*(max(etl)-min(etl)),['St. dev. of daily L/P = ',num2str(sigma)])
text(min(hp)+.1*(max(hp)-min(hp)),max(etl)-.4*(max(etl)-min(etl)),['Confidence level = ',num2str(cl_label),'%'])
%
% Axis labels
%
xlabel('Holding period','Fontweight','bold');
ylabel('ETL','rotation',0,'horizontal','right','Fontweight','bold');
title('Normal ETL against holding period','FontSize',12,'Fontweight','bold');