function normaltaillossesbacktest(PandL,cl)
% NORMALTAILLOSSESLBACKTEST Backtest on normal tail losses  
%
% Function carries out a tail losses backtest for a normal VaR 
% risk measurement model, for specified VaR confidence level. 
%
% The first argument is a vector of portfolio P/L observations, and the 
% second is the VaR confidence level.
%
% The function performs a Kolmogorov-Smirnov test to assess the 
% null hypothesis that the losses in excess of VaR are 
% consistent with the assumed P/L (or L/P) distribution function. 
% 
% The output consists of a plot of the predicted vs. empirical cdfs, and
% the probability that the null hypothesis is correct given a specified
% alternative hypothesis.
% 
% An additional optional output useful for comparison is the probability 
% that the null hypothesis is correct derived from the Kupiec test procedure. 
% 
% Reference: R.A. Baker, "kstest" (Kolmogorov-Smirnov test). Matlab Statistics
% Toolbox, $Revision: 1.4 $   $ Date: 1998/01/30 13:45:34.
%
% Revised by Kevin Dowd, November 6th, 2001.
% ***************************************************************
%
% Identify parameters and VaR
%
mu=mean(PandL) % Mean P/L
sigma=std(PandL) % Standard deviation of P/L
VaR=normalvar(PandL,cl,1) % Normal VaR
n=length(PandL); % Number of obsevations
%
% Determine tail losses
%
index=find(-PandL>VaR);
t=length(index); % Number of tail losses
%
LandP=-PandL; % Construct L/P series
LandP=sort(LandP); % Sorts losses into order
tail_losses=LandP(LandP>VaR); % Derives tail losses
% 
% Calculate empirical cdf for plot
% 
empirical_cdf=cdfcalc(LandP);
empirical_cdf=empirical_cdf(empirical_cdf>0);
%
% Calculate predicted cdf
%
for i=1:1
  predicted_cdf(i)=0;
end
for i=2:n
  predicted_cdf(i)=normcdf(LandP(i),-mu,sigma); % Normal CDF
end
predicted_cdf=predicted_cdf';
%
% Plotting
%
plot(LandP,empirical_cdf,LandP,predicted_cdf)
axis([VaR max(tail_losses) cl 1]);
xlabel('Losses in excess of VaR','Fontweight','bold');
ylabel('Cumulative probability','Fontweight','bold');
title(['Predicted and Empirical Excess Losses'],'FontSize',12,'Fontweight','bold');
whitebg;
%
% Derive cdf for predicted tail observations
%
predicted_cdf=predicted_cdf(LandP>VaR);
for i=1:1
    adj_pred_cdf(i)=(predicted_cdf(i)-cl)/(1-cl);
end
for i=2:t
    adj_pred_cdf(i)=(predicted_cdf(i)-predicted_cdf(i-1))/(1-cl)+...
        adj_pred_cdf(i-1);
end
% 
CDF=[tail_losses adj_pred_cdf'];
%
% Show total PandL, total tail losses, and effective sample size
%
Number_of_observations=n % This gives number of observations
Number_of_excess_losses=t % This gives number of excess losses
Ne=(t^2)/(2*t); % Ne is effective number of data points
Effective_sample_size=Ne
%
% Kolmogorov-Smirnov test statistics and probabilities
% 
%    Three alternative KS approaches, depending on alternative hypothesis
%
[H Prob KSstat]=kstest(tail_losses,CDF,0.05,0); 
KSstat
% Refers to 2-sided alternative hypothesis in which empirical and predicted cdfs differ
% This is set up as the default. COMMENT: INSERT % TWO LINES EARLIER TO DEACTIVATE
%
% [H Prob]=kstest(tail_losses,CDF,0.05,1); COMMENT: DELETE % TO ACTIVATE
% Refers to 1-sided alternative hypothesis in which empirical cdf exceeeds predicted
% cdf
% Alternative hypothesis is that tail losses are less than predicted
%
% [H Prob]=kstest(tail_losses,CDF,0.05,-1); COMMENT: DELETE % TO ACTIVATE
% Refers to 1-sided alternative hypothesis in which empirical cdf is less than
% predicted cdf
% Alternative hypothesis is that tail losses are greater than predicted
%
% Probability that null hypothesis is true, given alternative
%
Prob_of_null_hypothesis=Prob
%
% For comparison: Probability of null derived from Kupiec test
% 
Kupiec_prob_of_null=binopdf(t,n,1-cl)
