function y=tvarplot2D_cl(varargin)
% TVARPLOT2D_CL Plots t VaR against confidence level 
%
% Function plots the VaR of a portfolio against confidence level, assuming L/P is t distributed,
% for specified range of confidence level and a given holding period.
% 
% If there are four arguments, the first argument is a vector of daily P/L data, the second
% is the number of degrees of freedom, the third is the VaR confidence level, and the 
% last is the VaR holding period in days. 
% 
% If there are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the number of degrees
% of freedom, the fourth is the VaR confidence level, and the fifth is the VaR holding period. 
% 
% cl must be a vector, and hp must be a scalar.
%
% Source: M. Evans, N. Hastings, and B. Peacock "Statistical Distributions", 3rd edition, New York:
% John Wiley, chapters 38 and 39.
%
% Revised by Kevin Dowd, November 4th, 2001.
% *****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that arguments
% are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin ==5
    mu=varargin{1};
    sigma=varargin{2};
    df=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    df=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[df_row,df_col]=size(sigma);
if max(df_row,df_col)>1
    error('Number of degrees of freedom must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a scalar ');
end
% 
% To check that cl is read as a row vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if df<3
    error('Number of degrees of freedom must be at least 3 for first two moments of distribution to be defined.');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*sqrt((df-2)/df)*tinv((1-cl),df)-mu*hp'*ones(size(cl)); %t-VaR 
% 
% Plotting
%
plot(cl,var);
axis;
%
% Input data labels
%
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.1*(max(var)-min(var)),'Input parameters','Fontweight','bold')
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.2*(max(var)-min(var)),['Daily mean L/P = ',num2str(-mu)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.3*(max(var)-min(var)),['St. dev. of daily L/P = ',num2str(sigma)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.4*(max(var)-min(var)),['Degrees of freedom  = ',num2str(df)])
text(min(cl)+.1*(max(cl)-min(cl)),max(var)-.5*(max(var)-min(var)),['Holding period = ',num2str(hp),' day(s)'])
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('VaR','rotation',0,'horizontal','right','Fontweight','bold');
title(['t VaR against confidence level'],'FontSize',12,'Fontweight','bold')

