function y=upandoutcallprice(stock_price,strike,barrier,r,q,sigma,maturity)
% UPANDOUTCALLPRICE Price for up and out call
%
% Function derives the price of an up and out call option. 
%
% The first argument is the stock price, the second is the strike price, the third is 
% the barrrier, the fourth is the risk-free rate, the fifth is the dividend yield or foreign
% risk free rate, the sixth is volatility, and the seventh is the term to maturity. Rates 
% are expressed in annualised terms and maturity is in days.
%
% For up barriers, current stock price must be less than barrier.
% 
% Reference: Paul Wilmott, "Paul Wilmott on Quantitative Finance", Chichester and 
% New York: John Wiley, 2000, chapter 16.
%
% Revised by Kevin Dowd, February 13th, 2001.
% *****************************************************************************************
% 
% Convert maturity from units of days to units of years
%
maturity=maturity/360;
%
s=stock_price;
x=strike;
sb=barrier;
%
% Check that barrier is above current stock price
%
if s>sb
    y=0;
end
if s<sb
    % 
% Define a and b
%
a=(sb/s)^(-1+2*(r-q)/sigma^2);
b=(sb/s)^(1+2*(r-q)/sigma^2);
%
% Derive d terms
%
d1=(log(s/x)+(r-q+(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d2=(log(s/x)+(r-q-(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d3=(log(s/sb)+(r-q+(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d4=(log(s/sb)+(r-q-(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d5=(log(s/sb)-(r-q-(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d6=(log(s/sb)-(r-q+(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d7=(log(s/sb^2)-(r-q-(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d8=(log(s/sb^2)-(r-q+(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
%
% Option price
%
y=s*exp(-q*maturity)*(normcdf(d1)-normcdf(d3)-b*(normcdf(d6)-normcdf(d8)))-x*exp(-r*maturity)*(normcdf(d2)-normcdf(d4)-a*(normcdf(d5)-normcdf(d7)));
end