function y=cdf_of_sum_using_product_copula(quantile,mu1,mu2,sigma1,sigma2)
% Derives prob(X+Y<quantile) using product copula using normal marginals
%
% If X and Y are position P/Ls, then the VaR is equal to minus quantile. In
% such cases, we insert the negative of the VaR as the quantile, and the
% function gives us the value of 1 minus VaR confidence level. In other
% words, if X and Y are position P/Ls, the quantile is the negative of the
% VaR, and the output is 1 minus the VaR confidence level.
%
% Inputs:
%   Quantile (or negative of VaR, if X and Y are position P/Ls.
%   Portfolio quantile (or negative of VaR, if X and Y are position P/Ls).
%   mu1: Mean of P/L on first position.
%   mu2: Mean of P/L on second position.
%   sigma1: Std of P/L on first position.
%   sigma2: Std of P/L on second position.
%
% This function implements the approach described in Dowd-Fackler FEN 2004.
%
% Reference:
%   K. Dowd and P. Fackler "Estimating VaR with copulas," Financial
%   Engineering News, 2004.
%
% Written by Kevin Dowd, with acknowledgements to Paul Fackler and Peter
% Oliver, October 7, 2004.
% *************************************************************************
%
% Define w variable
%
w_min=0.001; w_max=0.999; % Specify min and max of w
dw=0.001; % Specify incremental change in w, ie, dw
w=w_min:dw:w_max; % Define w-variable going from min to max in units of size dw
%
% Obtain 'first' and 'second' sets of copula values corresponding to values of w
%   NB: The difference between the 'first' and 'second' goes into the
%   calculation of the approximate copula differential
%
for i=1:length(w);
    first_copula(i)=productcopula(w(i),normcdf(quantile-norminv(w(i),mu1,sigma1),mu2,sigma2)); 
end
for i=2:length(w);
    second_copula(i)=productcopula(w(i)-dw,normcdf(quantile-norminv(w(i),mu1,sigma1),mu2,sigma2)); 
end
%
% Obtain approximate copula differentials from the above
%
for i=2:length(w)
    approximate_copula_differential(i)=(first_copula(i)-second_copula(i))/dw;
end
%
% Obtain cdf
%
y=sum(approximate_copula_differential)*dw;
%
% ************************************************************************
% ************************************************************************
function y=productcopula(u,v)
% Derives value of product copula 
%
% Inputs:
%    * u is value of first marginal for random variable X: this is equal to
%       Prob(X<x)
%    * v is value of second marginal for random variable Y: this is equal to
%       Prob(Y<y) 
% *************************************************************************
y=u*v;



