function y=gaussian_copula_VaR(mu1,mu2,sigma1,sigma2,rho,number_steps_in_copula,cl)
% Derives VaR using bivariate gaussian copula with specified inputs, for normal
% marginals. 
%
% Inputs:
%   mu1: Mean of P/L on first position.
%   mu2: Mean of P/L on second position.
%   sigma1: Std of P/L on first position.
%   sigma2: Std of P/L on second position.
%   Correlation between P/Ls on two positions.
%   Number of steps used in the copula approximation (approximation being needed 
%       because Gaussian copula lacks a closed form solution).
%   VaR confidence level.
% 
% Notes:
%   1. This works only for bivariate gaussian copula, for normal marginals.
%      Normal marginals based on specified mu, sigma parameters for each
%      position.
%   2. Routine is based on three arbitrary params: lower and upper search
%      bounds for bisection algorithm, and tolerance level. These can be
%      changed manually if desired.
%   3. This function calls the additional functions specified below, which
%      carry out calculations along the lines suggested in the Dowd-Fackler
%      FEN 2004 article. 
%   4. Should be able to increase accuracy by increasing number of steps (which makes
%      approximation to double integral better) or by using a more
%      sophisticated algorithm to estimate the double integral (the one used
%      below being crude).
%
% Outputs:
%   Estimate of copula-based VaR.
%   Analytical variance-covariance VaR (for comparison).
%   Error in copula-VaR estimate, taken as difference between VC VaR and 
%     copula VaR estimate).
%
% Reference:
%   K. Dowd and P. Fackler "Estimating VaR with copulas," Financial
%   Engineering News, 2004.
% 
% Written by Kevin Dowd, October 7, 2004.
% *************************************************************************
%
% Report params
%
mu1
mu2
sigma1
sigma2
rho
number_steps_in_copula
cl
%
p=1-cl; % p is tail prob or cdf
%
% For comparison, compute analytical normal VaR
%
portfolio_mu=mu1+mu2
portfolio_variance=[1 1]*[sigma1^2 rho*sigma1*sigma2; rho*sigma1*sigma2 sigma2^2]*[1;1]
portfolio_sigma=sqrt(portfolio_variance)
analytical_variance_covariance_VaR=-portfolio_mu-portfolio_sigma*norminv(p,0,1);
%
% Specify bounds arbitrarily (NB: Would need to change manually if these
% were inappropriate)
%
L=-portfolio_mu-5*portfolio_sigma; 
fL=cdf_of_sum_using_gaussian_copula(L,mu1,mu2,sigma1,sigma2,rho,number_steps_in_copula)-p;
sign_fL=sign(fL); 
U=-portfolio_mu+5*portfolio_sigma; 
fU=cdf_of_sum_using_gaussian_copula(U,mu1,mu2,sigma1,sigma2,rho,number_steps_in_copula)-p;
sign_fU=sign(fU);
if sign_fL==sign_fU
    error('Assumed bounds do not include answer')
end
%
% Bisection algorithm
%
tol=.0001; % Tolerance level (NB: change manually if desired)
while U-L>tol
    x=(L+U)/2 % Bisection carried out in terms of P/L quantile or minus VaR
    cum_prob=cdf_of_sum_using_gaussian_copula(x,mu1,mu2,sigma1,sigma2,rho,number_steps_in_copula);
    fx = cum_prob-p; 
    if sign(fx) == sign(fL)
       L = x; fL = fx;
    else
       U = x; fU = fx;
    end
end
y=-x; % VaR is negative of terminal x-value or P/L quantile
%
% Report variance-covariance VaR and error in copula VaR for comparison
%
analytical_variance_covariance_VaR
error_in_copula_VaR_estimate=analytical_variance_covariance_VaR-y
%
% *************************************************************************
% *************************************************************************
function y=cdf_of_sum_using_gaussian_copula(quantile,mu1,mu2,sigma1,sigma2,rho,number_steps_in_copula)
% Derives prob(X+Y<quantile) using Gaussian copula using normal marginals
%
% If X and Y are position P/Ls, then the VaR is equal to minus quantile. In
% such cases, we insert the negative of the VaR as the quantile, and the
% function gives us the value of 1 minus VaR confidence level. In other
% words, if X and Y are position P/Ls, the quantile is the negative of the
% VaR, and the output is 1 minus the VaR confidence level.
%
% Inputs:
%   Portfolio quantile (or negative of VaR, if X and Y are position P/Ls).
%   mu1: Mean of P/L on first position.
%   mu2: Mean of P/L on second position.
%   sigma1: Std of P/L on first position.
%   sigma2: Std of P/L on second position.
%   Correlation between P/Ls on two positions.
%   The number of steps used in the copula approximation.
%
% NB: Copula approximation arises because the copula is an integral, which
% we are trying to approximate through a discrete sum.
%
% This function implements the approach described in Dowd-Fackler FEN 2004.
% 
% Reference:
%   K. Dowd and P. Fackler "Estimating VaR with copulas," Financial
%   Engineering News, 2004.
%
% Written by Kevin Dowd, with acknowledgements to Paul Fackler and Peter
% Oliver, October 7, 2004.
% *************************************************************************
%
% Define w variable
%
w_min=0.001; w_max=0.999; % Specify min and max of w
dw=0.001;                 % Specify incremental change in w, ie, dw
w=w_min:dw:w_max; % Define w-variable going from min to max in units of size dw
%
% Obtain 'first' and 'second' sets of copula values corresponding to values of w
%   NB: The difference between the 'first' and 'second' goes into the
%   calculation of the approximate copula differential
%
for i=1:length(w);
    first_copula(i)=gaussiancopula(w(i),normcdf(quantile-norminv(w(i),mu1,sigma1),mu2,sigma2),0,number_steps_in_copula); 
end
for i=2:length(w);
    second_copula(i)=gaussiancopula(w(i)-dw,normcdf(quantile-norminv(w(i),mu1,sigma1),mu2,sigma2),0,number_steps_in_copula); 
end
%
% Obtain approximate copula differentials from the above
%
for i=2:length(w)
    approximate_copula_differential(i)=(first_copula(i)-second_copula(i))/dw;
end
%
% Obtain desired cdf
%
y=sum(approximate_copula_differential)*dw;
%
% ************************************************************************
% ************************************************************************
function y=gaussiancopula(u,v,rho,number_steps)
% Derives value of gaussian copula 
%
% Inputs:
%    * u is value of first marginal for random variable X: this is equal to
%       Prob(X<x)
%    * v is value of second marginal for random variable Y: this is equal to
%       Prob(Y<y) 
%    * rho is correlation coefficient between X and Y
%    * Number of steps used for each of x and y
%
%   NB: Applies to bivariate Gaussian copula only. 
% *************************************************************************
%
% Define x and y
%   NB These are hypothetical domains of the cdfs;without loss of generality we can
%   take these to be standard normal percentiles; this is because we are only 
%   using these to determine double integrals with limits u and v.
%
x_min=-3; x_max=norminv(u,0,1);
dx=(x_max-x_min)/number_steps;
x=x_min:dx:x_max;
y_min=-3; y_max=norminv(v,0,1);
dy=(y_max-y_min)/number_steps;
y=y_min:dy:y_max;
%
% Obtain copula as approximate double sum, which approximates the 'true'
% double integral
%
for i=1:length(x)
    for j=1:length(y)
        term(i,j)=exp(-(x(i)^2-2*rho*x(i)*y(j)+y(j)^2)/(2*(1-rho^2)));
    end
end
y=sum(sum(term))*dx*dy/(2*pi*(1-rho^2)^0.5);




