function y=gumbel_copula_VaR(mu1,mu2,sigma1,sigma2,beta,cl)
% Derives VaR using bivariate Gumbel copula with specified inputs, for normal
% marginals. 
%
% Inputs:
%   mu1: Mean of P/L on first position.
%   mu2: Mean of P/L on second position.
%   sigma1: Std of P/L on first position.
%   sigma2: Std of P/L on second position.
%   Gumbel copula parameter, beta (which must be at least 1)
%   VaR confidence level.
% 
% Notes:
%   1. This works only for bivariate Gumbel copula, for normal marginals.
%      Normal marginals based on specified mu, sigma parameters for each
%      position.
%   2. Routine is based on three arbitrary params: lower and upper search
%      bounds for bisection algorithm, and tolerance level. These can be
%      changed manually if desired.
%   3. This function calls the additional functions specified below, which
%      carry out calculations along the lines suggested in the Dowd-Fackler
%      FEN 2004 article. 
%
% Outputs:
%   Estimate of copula-based VaR.
%
% Reference:
%   K. Dowd and P. Fackler "Estimating VaR with copulas," Financial
%   Engineering News, 2004.
% 
% Written by Kevin Dowd, October 7, 2004.
% *************************************************************************
%
% Report params
%
mu1
mu2
sigma1
sigma2
if beta<=1
    error('Beta must be bigger than 1')
end
beta
cl
%
p=1-cl; % p is tail prob or cdf
%
% Compute portfolio mean and sigma (NB: These are used here to help compute
% initial bounds automatically)
%
portfolio_mu=mu1+mu2;
portfolio_variance=[1 1]*[sigma1^2 0; 0 sigma2^2]*[1;1];
portfolio_sigma=sqrt(portfolio_variance);
%
% Specify bounds arbitrarily (NB: Would need to change manually if these
% were inappropriate)
%
L=-portfolio_mu-5*portfolio_sigma; 
fL=cdf_of_sum_using_gumbel_copula(L,mu1,mu2,sigma1,sigma2,beta)-p;
sign_fL=sign(fL); 
U=-portfolio_mu+5*portfolio_sigma; 
fU=cdf_of_sum_using_gumbel_copula(U,mu1,mu2,sigma1,sigma2,beta)-p;
sign_fU=sign(fU);
if sign_fL==sign_fU
    error('Assumed bounds do not include answer')
end
%
% Bisection algorithm
%
tol=.0001; % Tolerance level (NB: change manually if desired)
while U-L>tol
    x=(L+U)/2 % Bisection carried out in terms of P/L quantile or minus VaR
    cum_prob=cdf_of_sum_using_gumbel_copula(x,mu1,mu2,sigma1,sigma2,beta);
    fx = cum_prob-p; 
    if sign(fx) == sign(fL)
       L = x; fL = fx;
    else
       U = x; fU = fx;
    end
end
y=-x; % VaR is negative of terminal x-value or P/L quantile
%
% *************************************************************************
% *************************************************************************
function y=cdf_of_sum_using_gumbel_copula(quantile,mu1,mu2,sigma1,sigma2,beta)
% Derives prob(X+Y<quantile) using Gumbel copula using normal marginals
%
% If X and Y are position P/Ls, then the VaR is equal to minus quantile. In
% such cases, we insert the negative of the VaR as the quantile, and the
% function gives us the value of 1 minus VaR confidence level. In other
% words, if X and Y are position P/Ls, the quantile is the negative of the
% VaR, and the output is 1 minus the VaR confidence level.
%
% Inputs:
%   Portfolio quantile (or negative of VaR, if X and Y are position P/Ls).
%   mu1: Mean of P/L on first position.
%   mu2: Mean of P/L on second position.
%   sigma1: Std of P/L on first position.
%   sigma2: Std of P/L on second position.
%   Gumbel copula parameter, beta (which must be at least 1)
%
% This function implements the approach described in Dowd-Fackler FEN 2004.
%
% Reference:
%   K. Dowd and P. Fackler "Estimating VaR with copulas," Financial
%   Engineering News, 2004.
%
% Written by Kevin Dowd, with acknowledgements to Paul Fackler and Peter
% Oliver, October 7, 2004.
% *************************************************************************
%
% Define w variable
%
w_min=0.001; w_max=0.999; % Specify min and max of w
dw=0.001; % Specify incremental change in w, ie, dw
w=w_min:dw:w_max; % Define w-variable going from min to max in units of size dw
%
% Obtain 'first' and 'second' sets of copula values corresponding to values of w
%   NB: The difference between the 'first' and 'second' goes into the
%   calculation of the approximate copula differential
%
for i=1:length(w);
    first_copula(i)=gumbelcopula(w(i),normcdf(quantile-norminv(w(i),mu1,sigma1),mu2,sigma2),beta); 
end
for i=2:length(w);
    second_copula(i)=gumbelcopula(w(i)-dw,normcdf(quantile-norminv(w(i),mu1,sigma1),mu2,sigma2),beta); 
end
%
% Obtain approximate copula differentials from the above
%
for i=2:length(w)
    approximate_copula_differential(i)=(first_copula(i)-second_copula(i))/dw;
end
%
% Obtain desird cdf
%
y=sum(approximate_copula_differential)*dw;
%
% ************************************************************************
% ************************************************************************
function y=gumbelcopula(u,v,beta)
% Derives value of Gumbel copula 
%
% Inputs:
%    * u is value of first marginal for random variable X: this is equal to
%       Prob(X<x).
%    * v is value of second marginal for random variable Y: this is equal to
%       Prob(Y<y). 
%    * Beta parameter for Gumbel copula.
% *************************************************************************
y=exp(-((-log(u))^beta+(-log(v))^beta))^1/beta;



