function y=frechetesplot2D_cl(mu,sigma,tail_index,n,cl,hp)
% Function plots the ETL of a portfolio against confidence level, assuming losses are Frechet distributed,
% for range of confidence levels and a given holding period.
% 
% Note that the long-right-hand tail is fitted to losses, not profits. 
%
% There are six arguments, the first is the assumed location parameter for daily L/P, the 
% second is the assumed scale parameter of daily L/P, the third is the tail index, the 
% fourth is the block size from which the maxima are drawn, the fifth is the VaR confidence 
% level, and the fifth is the VaR holding period. 
% 
% cl must be a vector, and cl must be a vector.
%
% Source: P. Embrechts, C. Kluppelberg and T. Mikosch, Modelling Extremal
% Events for Insurance and Finance. Berlin: Springer, 1997, p. 324, and R.-D. Reiss and 
% M. Thomas Statistical Analysis of Extreme Values from Insurance, Finance,
% Hydrology and Other Fields, Basel: Birkhaueser, 1997, pp. 15, 18.
%
% Revised by Kevin Dowd, February 28, 2005.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[tail_index_row,tail_index_col]=size(tail_index);
if max(tail_index_row,tail_index_col)>1
    error('Tail index must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% To check that cl is read as a row vector as required
% 
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that parameters obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if min(tail_index)<=0
    error('Tail index must be greater than 0');
end
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
zeta=tail_index;
%
% VaR estimation
%
var=frechetvar(mu,sigma,tail_index,n,cl,hp);        
%
% ES estimation
%
numuber_slices=1000;                   % Number of slices into which tail is divided 
cl0=cl;                                % Initial confidence level
term=var;                                                                                             
delta_cl=(1-cl)/numuber_slices;        % Increment to confidence level as each slice is taken
for i=1:numuber_slices-1
    cl=cl0+i*delta_cl;                 % Revised cl
    term=term+mu*ones(size(cl))-(sigma/tail_index)*(1-(-n*log(cl)).^-tail_index);   
    % NB Frechet term
end;
es=term/(numuber_slices-1);                                           % Frechet ES

%
% Plotting
%
plot(cl0,es);
axis;
cl_label=100*cl0;
%
% Input data labels
%
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(es)-.1*(max(es)-min(es)),'Input parameters','Fontweight','bold')
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(es)-.2*(max(es)-min(es)),['Location parameter for daily L/P = ',num2str(mu)])
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(es)-.3*(max(es)-min(es)),['Scale parameter for daily L/P = ',num2str(sigma)])
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(es)-.4*(max(es)-min(es)),['Tail index = ',num2str(tail_index)])
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(es)-.5*(max(es)-min(es)),['Holding period = ',num2str(hp),' days'])
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('ES','rotation',0,'horizontal','right','Fontweight','bold');
title('Frechet ES against confidence level','FontSize',12,'Fontweight','bold');


