function y=gumbeles(mu,sigma,n, cl,hp)
% Function estimates the ES of a portfolio assuming extreme losses are Gumbel distributed,
% for specified confidence level and holding period.
%
% Note that the long-right-hand tail is fitted to losses, not profits. 
%
% Arguments: the first is the assumed location parameter for daily L/P, the 
% second is the assumed scale paramater for daily L/P, the third is the assumed block 
% size from which the maxima are drawn, the fourth is the VaR confidence 
% level, and the fifth is the VaR holding period. 
% 
% If cl and hp are both scalars, function gives a scalar answer.
% If cl is a vector, and hp is a scalar, function gives a row vector of ESs.
% If cl is a scalar and hp is a vector, function  gives a column vector of ESs.
% If cl and hp are both vectors, function gives a matrix of ETLs with cl read across rows
% and hp down columns.
%
% Source: National Institute of Standards and Technology (1997) Dataplot Reference Manual. 
% Volume 1: Commands. NIST: Washington, DC, p. 8-67.
%
% Revised by Kevin Dowd, January 4th, 2004.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector  as required
% And to check that hp is read as a scalar or column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% VaR estimation
%
var=mu*ones(size(cl))-sigma*log(-n*log(cl))  % Gumbel VaR  
%
% ES estimation
%
number_slices=1000;                        % Number of slices into which tail is divided 
cl0=cl;                           % Initial confidence level
term=var;                                                                                             
delta_cl=(1-cl)/number_slices;       % Increment to confidence level as each slice is taken
for i=1:number_slices-1
cl=cl0+i*delta_cl;              % Revised cl
term=term+mu*ones(size(cl))-sigma*log(-n*log(cl));  %NB Gumbel term
end;
y=term/(number_slices-1);                                        % Gumbel ES

