function y=gumbelvar(mu,sigma,n,cl,hp)
% Function estimates the EV VaR of a portfolio assuming extreme losses are Gumbel distributed,
% for specified confidence level and holding period.
%
% Note that the long-right-hand tail is fitted to losses, not profits. 
% 
% Arguments: the first is the assumed location parameter for daily L/P, the 
% second is the assumed scale paramater for daily L/P, the third is the assumed block 
% size from which the maxima are drawn, the fourth is the VaR confidence 
% level, and the fifth is the VaR holding period. 
% 
% If cl and hp are both scalars, function gives a scalar answer.
% If cl is a vector, and hp is a scalar, function gives a row vector of
% VaRs
% If cl is a scalar and hp is a vector, function  gives a column vector of VaRs.
% If cl and hp are both vectors, function gives a matrix of VaRs with cl read across rows
% and hp down columns.
%%
% Revised by Kevin Dowd, February 28, 2005.
% *****************************************************************************************
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mu must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a scalar or a vector');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a scalar or a vector');
end
% 
% To check that cl is read as a scalar or row vector  as required
% And to check that hp is read as a scalar or column vector as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence level(s) must be less than 1');
end
if min(cl)<=0
    error('Confidence level(s) must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% VaR estimation
%
y=mu*ones(size(cl))-sigma*log(-n*log(cl));   % Gumbel VaR  