function y=hsesdfperc(PandL_data,perc,cl)
% HSESDFPERC Percentiles of historical simulation VaR distribution function 
%
% Estimates percentiles of historical simulation ES distribution function, using the theory 
% of order statistics, for specified confidence level.
%
% The first argument is a vector of daily P/L data, the second is the desired percentile, the 
% third is the VaR confidence level. 
% 
% Note that the output is a scalar, and the desired percentile and cl are scalars.
%
% Revised by Kevin Dowd, November 26th, 2001.
% ****************************************************************************
% 
% Determine if there are three arguments, and ensure that arguments
% are read as intended
%
if nargin<3,
    error('Too few arguments');
end
if nargin>3,
    error('Too many arguments');
end
if nargin ==3
    data=sort(PandL_data);
    n=length(data);
end
% 
% Check that inputs have correct dimensions
%
[n_row,n_col]=size(n);
if max(n_row,n_col)>1
    error('Number of observations in sample must be a scalar');
end
if n-round(n)>0|n-round(n)<0             % Checks that n is an integer
    error('Number of observations in sample must be an integer')
end
[perc_row,perc_col]=size(perc);
if max(perc_row,perc_col)>1
    error('Chosen percentile of OS distribution must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar');
end
%
% Check that inputs obey sign and value restrictions
%
if n<0
    error('Number of observations must be greater than zero')
end
if perc<=0
    error('Chosen percentile must be positive')
end
if perc>1
    error('Chosen percentile must not exceed 1')
end
if cl>=1
    error('Confidence level must be less than 1');
end
%
% Derive order statistic and ensure it is an integer
%
w=n*cl;                % Derive r-th order statistic 
r=round(w);            % Round r to nearest integer
% 
% Bisection routine 
%
a = 0; fa = -Inf;
b = 1; fb = Inf;
while b-a > eps*b
   x = (a+b)/2;
   fx = 1-binocdf(r-1,n,x)-perc;
   if sign(fx) == sign(fa)
      a = x; fa = fx;
   else
      b = x; fb = fx;
   end
end
x;                                   % OS cdf value
n;
i=round(n*x);
var=data(i) ;             % Value of percentile of VaR distribution function; 
j=i:n;
y=mean(data(j));          % Value of percentile of ES distribution function;

