function y=lognormalesplot2D_cl(varargin)
% LOGNORMALESPLOT2D_CL Plots lognormal ES against confidence level 
%
% Function plots the ES of a portfolio against confidence level, assuming
% geometric returns are normally distributed, for specified range of 
% confidence level and a given holding period.
% 
% If there are four arguments, the first argument is a vector of daily
% geometric return data, the second is the size of the investment, the 
% third is the VaR confidence level vector, and the fourth is the VaR holding
% period in days. 
% 
% If there are five arguments, the first is the assumed daily mean geometric 
% return, the second is the assumed standard deviation of daily geometric 
% returns, the third is the size of the investment, the fourth is the 
% VaR confidence level, and the fifth is the VaR holding period. 
% 
% cl must be a vector, and hp must be a scalar.
%
% Revised by Kevin Dowd, November 11th, 2001.
% *****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that 
% arguments are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin==5
    mu=varargin{1};
    sigma=varargin{2};
    investment=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    investment=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence level must be a vector');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
% 
% To check that cl is read as a row vector  as required
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if max(cl)>=1
    error('Confidence levels must be less than 1');
end
if min(cl)<=0
    error('Confidence levels must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
var=investment-exp(sigma*sqrt(hp')*norminv(1-cl,0,1)+mu*hp'*ones(size(cl))...
    +log(investment)); % VaR 
% 
% ES estimation
%
n=1000;                            % Number of slices into which tail is divided 
cl0=cl;                            % Initial confidence level
v=var;                                                
delta_cl=(1-cl)/n;                 % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                 % Revised cl
v=v+investment-exp(sigma*sqrt(hp')*norminv(1-cl,0,1)+mu*hp'*ones(size(cl))...
    +log(investment));
end;
v=v/n;                                                  % ES
%
% Plotting
%
plot(cl0,v);
axis;
%
% Input data labels
%
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.1*(max(v)-min(v)),'Input parameters','Fontweight','bold');
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.2*(max(v)-min(v)),['Daily mean geometric return = ',num2str(-mu)]);
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.3*(max(v)-min(v)),['St. dev. of daily geometric returns = ',num2str(sigma)]);
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.4*(max(v)-min(v)),['Investment size = ',num2str(investment)])
text(min(cl0)+.1*(max(cl0)-min(cl0)),max(v)-.5*(max(v)-min(v)),['Holding period = ',num2str(hp),' day(s)']);
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('ES','rotation',0,'horizontal','right','Fontweight','bold');
title(['Lognormal ES against confidence level'],'FontSize',12,'Fontweight','bold');
