function y=adjustednormaleshotspots(vc_matrix,mu, skew, kurtosis, positions,cl,hp)
% Hot spots for ES adjusted by Cornish-Fisher correction
%
% Function estimates the ETL hot spots (or vector of incremental ETLs) for a portfolio 
% with portfolio return adjusted for non-normality by Cornish-Fisher correction, 
% for specified confidence level and holding period.
% 
% The first argument is the assumed variance-covariance matrix for returns, the second
% is the vector of expected position returns, the third is the return skew, the fourth is the 
% return kurtosis, the fifth is the vector of positions, the sixth is the VaR confidence level 
% (scalar), and the last is the VaR holding period (scalar). 
%
% Revised by Kevin Dowd, February 20th, 2001.
% *****************************************************************************************
% 
% To check that positions vector read as a scalar or row vector 
%
[positions_rows,positions_cols]=size(positions);
if positions_rows>positions_cols
    positions=positions';
end
% 
% To check that expected returns vector is read as a scalar or row vector 
%
[mu_rows,mu_cols]=size(mu);
if mu_rows>mu_cols
    mu=mu';
end
%
% Check that dimensions are correct
%
if max(size(mu))~=max(size(positions))
    error('Positions vector and expected returns vector must have same size')
end
if max(size(positions))~=max(size(vc_matrix))
    error('Positions vector and variance-covariance matrix must have compatible dimensions')
end
%
% Check that inputs obey sign and value restrictions
%
if cl>=1
    error('Confidence level must be less than 1');
end
if cl<=0
    error('Confidence level must be greater than 0');
end
if hp<=0
    error('Holding period must be greater than 0');
end
%
% VaR and ES estimation
%
%        Begin with portfolio ES
%
z=norminv(1-cl,0,1);
sigma=positions*vc_matrix*positions'/(sum(positions)^2); % initial standard deviation of portfolio returns
adjustment=(1/6)*(z^2-1)*skew+(1/24)*(z^3-3*z)*(kurtosis-3)-(1/36)*(2*z^3-5*z)*skew^2;
var=-mu*positions'*hp-(z+adjustment)*sigma*(sum(positions)^2)*sqrt(hp); % Initial VaR
%
n=1000;                                     % Number of slices into which tail is divided 
cl0=cl;                                        % Initial confidence level
term=var;                                                                                             
delta_cl=(1-cl)/n;                    % Increment to confidence level as each slice is taken
     for k=1:n-1
        cl=cl0+k*delta_cl;           % Revised cl
        z=norminv(1-cl,0,1);
        adjustment=(1/6)*(z^2-1)*skew+(1/24)*(z^3-3*z)*(kurtosis-3)-(1/36)*(2*z^3-5*z)*skew^2;
        term=term-mu*positions'*hp-(z+adjustment)*sigma*(sum(positions)^2)*sqrt(hp); 
     end;
portfolio_es=term/n;                                           % Portfolio ETL
%
for j=1:length(positions)
    x=positions;
    x(j)=0;
    sigma=x*vc_matrix*x'/(sum(x)^2); 
    term(j)=-mu*x'*hp-norminv(1-cl,0,1)*x*vc_matrix*x'*sqrt(hp);                                                                                           
    for k=1:n-1
        cl=cl0+k*delta_cl;           % Revised cl
        z=norminv(1-cl,0,1);
        adjustment=(1/6)*(z^2-1)*skew+(1/24)*(z^3-3*z)*(kurtosis-3)-(1/36)*(2*z^3-5*z)*skew^2;
        term(j)=term(j)-mu*x'*hp-norminv(1-cl,0,1)*x*vc_matrix*x'*sqrt(hp);
     end;
    es(j)=term(j)/n;                                           % ES on portfolio minus position j
    is(j)=portfolio_es-es(j);                                             % Incremental ES
end
y=ies;


