function y=normalesdfperc(varargin)
% NORMALESDFPERC Percentiles of ES distribution function for normally distributed P/L
%
% Estimates percentiles of ES distribution function for normally distributed P/L, using the theory 
% of order statistics.
%
% If there are four arguments, the first argument is a vector of daily P/L data, the second is the 
% desired percentile, the third is the VaR confidence level, and the fourth is the VaR holding period in days. 
% 
% If there are six arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the assumed sample size,
% the fourth is the desired percentile of the OS distribution, the fifth is the VaR confidence 
% level, and the sixth is the VaR holding period. 
% 
% Note that the output is a scalar, and mu, sigma, n, desired percentile, cl and hp are scalars.
% 
% Revised by Kevin Dowd, February 22, 2005.
%****************************************************************************
% 
% Determine if there are four or six arguments, and ensure that arguments
% are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin==5
    error('Incorrect number of arguments')
end
if nargin>6,
    error('Too many arguments');
end
if nargin ==6
    mu=varargin{1};
    sigma=varargin{2};
    n=varargin{3};
    perc=varargin{4};
    cl=varargin{5};
    hp=varargin{6};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    n=length(varargin{1});
    perc=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[n_row,n_col]=size(n);
if max(n_row,n_col)>1
    error('Number of observations in sample must be a scalar');
end
if n-round(n)>0|n-round(n)<0             % Checks that n is an integer
    error('Number of observations in sample must be an integer')
end
[perc_row,perc_col]=size(perc);
if max(perc_row,perc_col)>1
    error('Chosen percentile of OS distribution must be a scalar');
end
[cl_row,cl_col]=size(cl);
if max(cl_row,cl_col)>1
    error('Confidence level must be a scalar ');
end
[hp_row,hp_col]=size(hp);
if max(hp_row,hp_col)>1
    error('Holding period must be a scalar');
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if n<0
    error('Number of observations must be greater than zero')
end
if perc<=0
    error('Chosen percentile must be positive')
end
if perc>1
    error('Chosen percentile must not exceed 1')
end
if cl>=1
    error('Confidence level must be less than 1');
end
if cl<=0
    error('Confidence level must be greater than 0');
end
if hp<=0
    error('Holding period must be greater than 0');
end
%
% Derive order statistic and ensure it is an integer
%
w=n*cl;         % Derive r-th order statistic 
r=round(w);     % Round r to nearest integer
% 
% Bisection routine 
%
a = 0; fa = -Inf;
b = 1; fb = Inf;
while b-a > eps*b
   x = (a+b)/2;
   fx = 1-binocdf(r-1,n,x)-perc;
   if sign(fx) == sign(fa)
      a = x; fa = fx;
   else
      b = x; fb = fx;
   end
end
x;                                            % OS cdf value
var_perc=norminv(x,-mu*hp,sigma*sqrt(hp)); % Value of VaR percentile; note normal VaR formula
%
% ES_percentile estimation
%
y=sigma*sqrt(hp')*normpdf(var_perc,0,1)/(1-cl)-mu*hp'*ones(size(cl)); % Value of ES percentile
