function normalspectralriskmeasure(mu,sigma,gamma,number_of_slices)
% Function estimates the spectral risk measure of a portfolio 
% assuming losses are normally distributed, assuming exponential weighting
% function with specified gamma.
% 
% Inputs:
%   Mean losses.
%   Std losses.
%   Gamma: gamma parameter in exponential risk aversion function.
%   Number of slices into which density function is divided.
%
% Revised by Kevin Dowd, January 12, 2005.
% *************************************************************************
tic
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if min(gamma)<=0
    error('Gamma must be greater than 0');
end
% 
% Report params
%
mu
sigma
gamma
n=number_of_slices; number_of_slices
%
% CRUDE (WEIGHTED AVERAGE QUANTILE) ESTIMATE OF RISK MEASURE
%
crude_estimate_of_risk_measure=crude_estimate_of_spectral_risk_measure(mu,sigma,gamma,n)
crude_halving_error=crude_estimate_of_risk_measure-crude_estimate_of_spectral_risk_measure(mu,sigma,gamma,n/2)
%
% TRAPEZOIDAL RULE ESTIMATE OF RISK MEASURE
% 
trapezoidal_estimate=trapezoidal_quadrature_estimate(mu,sigma,gamma,n)
trapezoidal_halving_error=(1/3)*(trapezoidal_estimate-trapezoidal_quadrature_estimate(mu,sigma,gamma,n/2))
%
% SIMPSON'S RULE ESTIMATE OF RISK MEASURE
% 
simpsons_estimate=simpsons_quadrature_estimate(mu,sigma,gamma,n)
simpsons_halving_error=(1/15)*(simpsons_estimate-simpsons_quadrature_estimate(mu,sigma,gamma,n/2))

toc
% *************************************************************************
% *************************************************************************
function y=crude_estimate_of_spectral_risk_measure(mu,sigma,gamma,n)
% Function applies crude average approach to estimate exponential spectral risk measure. 
% 
% Inputs:
%   mu: mean losses
%   sigma: std losses
%   gamma: gamma weight in exponential spectral risk aversion function
%   n: number of slices.
%
% Revised by Kevin Dowd, January 12, 2005.
% *************************************************************************
%
p=1/n:1/n:(n-1)/n; % Cumulative probs
for i=1:n-1
    var(i)=mu+sigma*norminv(p(i),0,1); % VaRs
    phi(i)=exp(-(1-p(i))/gamma)/(gamma*(1-exp(-1/gamma))); % Weights
    product(i)=var(i)*phi(i); % Weighed VaR
end;
%
y=sum(product)/(n-1); % Crude estimate of exponential spectral risk measure
%
% *************************************************************************
% *************************************************************************
function y=trapezoidal_quadrature_estimate(mu,sigma,gamma,n)
% Function applies trapezoidal rule to estimate integral of  
% f(x) numerically using trapezoidal rule with given n, where f(x)
% is the function in the exponential spectral risk measure. 
% 
% Inputs:
%   mu: mean losses
%   sigma: std losses
%   gamma: gamma weight in exponential spectral risk aversion function
%   n: number of slices.
%
% Revised by Kevin Dowd, January 12, 2005.
% *************************************************************************
%
a=1/n; b=(n-1)/n;      % Limits of integration, bearing in mind we wish to avoid limits of 
                       %      0 and 1 because inverses may not be not defined
h=(b-a)/(n-1);         % Increment
for i=1:n              % Domain of integration, x
    p(i)=a+(i-1)*h; 
end           
w(1)=h/2; w(n)=h/2;    % Initial trap weights
for i=2:n-1            % Other trap weights
    w(i)=h;
end
%
% Specify f(x) 
%
for i=1:n
    var(i)=mu+sigma*norminv(p(i),0,1); % VaRs
    phi(i)=exp(-(1-p(i))/gamma)/(gamma*(1-exp(-1/gamma))); % Spectral weights in risk measure
    f(i)=var(i)*phi(i); % f(i), weighted VaR
end
%
y=w*f'; 
% *************************************************************************
% *************************************************************************
function y=simpsons_quadrature_estimate(mu,sigma,gamma,n)
% Function applies Simpson's rule to estimate integral of  
% f(x) numerically using Simpson's rule with given n, where f(x)
% is the function in the exponential spectral risk measure. 
% 
% Inputs:
%   mu: mean losses
%   sigma: std losses
%   gamma: gamma weight in exponential spectral risk aversion function
%   n: number of slices. NB: must be even.
%
% Revised by Kevin Dowd, January 12, 2005.
% *************************************************************************
%
n=n-1; % Convert to odd for purposes of algorithm
a=1/n; b=(n-1)/n;      % Limits of integration, bearing in mind we wish to avoid limits of 
                       %      0 and 1 because inverses may not be not defined
h=(b-a)/(n-1);         % Increment
for i=1:n              % Domain of integration, x
    p(i)=a+(i-1)*h; 
end 
%
% Simpson's rule weights
% 
w(1)=h/3; w(n)=h/3;    % Initial trap weights
for i=2:2:n-1          % Even trap weights
    w(i)=4*h/3;
end
for i=3:2:n-2          % Odd trap weights
    w(i)=2*h/3;
end
%
% Specify f(x) 
%
for i=1:n
    var(i)=mu+sigma*norminv(p(i),0,1); % VaRs
    phi(i)=exp(-(1-p(i))/gamma)/(gamma*(1-exp(-1/gamma))); % Spectral weights in risk measure
    f(i)=var(i)*phi(i); % f(i), weighted VaR
end
%
y=w*f'; 

