function americanputes_binomial(amount_invested,stock_price,strike,r,...
    volatility,maturity,number_steps,hp,cl 
% Estimates ES of American vanilla call using binomial tree. 
%       
% The arguments are the following: the amount invested, the current 
% underlying price, the strike, the risk-free rate, the volatility of 
% theunderlying, the time to maturity (in days), the number of steps 
% in the binomial tree, the VaR confidence level and the holding period. 
% 
% Revised by Kevin Dowd, November 7th, 2001.
% **********************************************************************************
tic 
%
S=stock_price;
t=maturity;
sigma=volatility;
%
% Convert maturity and holding period from units of days to years
%
t=t/360;
hp=hp/360;
%
% Calculate the length of each interval, dt, and number of steps to end
% of holding period.
%
N=number_steps       % Number of steps to option expiry
dt = t/N         % Length of time step 
M=round(hp/dt)   % Number of steps to end of holding period
%
% Calculate movements and associated probabilities 
%
u = exp(sigma.*sqrt(dt)); 
d = 1./u; 
a = exp((r-q).*dt); 
p = (a-d)./(u-d); 
%
jspan = -fix(N*.5);          % j-th node offset number 
ispan = rem(round(t/dt),2);  % i-th node offset number 
i = ispan:(N+ispan);         % i-th node numbers 
j = (jspan:(N+jspan))';      % j-th node numbers 
jex = j(:,ones(size(i')));   % expand i and j to eliminate for loop 
iex = i(ones(size(j)),:); 
% 
% values 
% 
% Asset price at nodes, matrix is flipped so tree appears correct 
% visually 
%
pr = triu(fliplr(flipud(S.*u.^jex.*d.^(iex-jex))));   
%
% Option valuation along tree
%
opt = zeros(size(pr));           
  opt(:,N+1) = max(X-pr(:,N+1),0);  % Determine final option value from underlying price 
  for n = N:-1:1 
    k = 1:n; 
    % Probable option values discounted back one time step 
    discopt = (p*opt(k,n+1)+(1-p)*opt(k+1,n+1))*exp(-r*dt); 
    % Option value is max of X - current price or discopt 
    opt(:,n) = [max(X-pr(1:n,n),discopt);zeros(N+1-n,1)]; 
end 
%
% Initial option price and number of options in portfolio
%
initial_option_price=opt(1,1) % Initial option price
number_options=amount_invested/initial_option_price
%
% Option tree values at end of holding period
%
end_hp_option_price=opt(:,M+1);
end_hp_option_price=end_hp_option_price(1:M+1)
%
% Option position P/L
% 
Profit_or_loss=(end_hp_option_price-initial_option_price).*...
    number_options 
%
% VaR and ES
%
var=hsvar(Profit_or_loss,cl);
if var==amount_invested
    es=var;
else
    es=hses(Profit_or_loss,cl);
end
%
% Main outputs
% 
es 
%
toc
