function y=blackscholescalles_sim(amount_invested,stock_price,strike,r,mu,sigma,maturity,....
    number_trials,cl,hp)
% ES of Black-Scholes call position estimated by Monte Carlo simulation
%
% Function estimates the ES of a Black-Scholes call option position 
% using Monte Carlo simulation.
%
% The arguments are: the amount invested, the current stock price, the strike 
% price, the risk-free rate, the expected rate of return on the underlying asset,
% the stock volatility, the term to maturity, the number of iterations in the 
% Monte Carlo simulation exercise, the VaR confidence level and the VaR holding
% period. 
%
% The returns and volatility are in annualised terms, and the maturity and holding]
% period are in days. The amount invested is positive (negative) if the option 
% position is long (short).
%
% NB: cl and hp are scalars.
%
% Revised by Kevin Dowd, November 4th, 2001.
% ****************************************************************************
tic % Start timer
%
% Precompute constants
%
annual_maturity=maturity/360; % Annualised maturity
annual_hp=hp/360; % Annualised holding period
N=1; % Number of steps - only one needed for BS option
dt=annual_hp/N; % Size of time-increment equal to holding period
nudt=(mu-0.5*sigma^2)*dt;
sigmadt=sigma*sqrt(dt);
lnS=log(stock_price);
M=number_trials;
initial_option_price=blackscholescallprice(stock_price,strike,r,sigma,maturity);
number_of_options=abs(amount_invested)/initial_option_price;
%
% Stock price simulation process
%
for i=1:M
    lnSt(i)=lnS+nudt+sigmadt*randn; % Random stock price movement
    new_stock_price(i)=exp(lnSt(i)); % New stock price
end
%
% P/L calculation
% 
if amount_invested>0 % If option position is long
    for i=1:M
        Profit_or_loss(i)=(blackscholescallprice(new_stock_price(i),strike,r,sigma,...
            maturity-hp)-initial_option_price)*number_of_options;
    end
end
if amount_invested<0 % If option position short
    for i=1:M
        Profit_or_loss(i)=(-blackscholescallprice(new_stock_price(i),strike,r,sigma,...
            maturity-hp)+initial_option_price)*number_of_options;
    end
end
%
% VaR estimation
%
y=hses(Profit_or_loss,cl) % VaR 
%
toc % End timer