function y=tesplot2D_hp(varargin)
% TESPLOT2D_HP Plots t VaR against hodling period 
%
% Function plots the ES of a portfolio against holding period, assuming L/P is t distributed,
% for a given confidence level and a range of holding periods.
% 
% If there are four arguments, the first argument is a vector of daily P/L data, the second
% is the number of degrees of freedom, the third is the VaR confidence level, and the 
% last is the VaR holding period in days. 
% 
% If there are five arguments, the first is the assumed mean daily P/L, the 
% second is the assumed standard deviation of daily P/L, the third is the number of degrees
% of freedom, the fourth is the VaR confidence level, and the fifth is the VaR holding period. 
% 
% cl must be a scalar and hp must be a vector.
%
% Source: M. Evans, N. Hastings, and B. Peacock "Statistical Distributions", 3rd edition, New York:
% John Wiley, chapters 38 and 39.
%
% Revised by Kevin Dowd, November 4th, 2001.
% *****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that arguments
% are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin ==5
    mu=varargin{1};
    sigma=varargin{2};
    df=varargin{3};
    cl=varargin{4};
    hp=varargin{5};
end
if nargin==4
    mu=mean(varargin{1});
    sigma=std(varargin{1});
    df=varargin{2};
    cl=varargin{3};
    hp=varargin{4};
end
% 
% Check that inputs have correct dimensions
%
[mu_row,mu_col]=size(mu);
if max(mu_row,mu_col)>1
    error('Mean must be a scalar');
end
[sigma_row,sigma_col]=size(sigma);
if max(sigma_row,sigma_col)>1
    error('Standard deviation must be a scalar');
end
[df_row,df_col]=size(sigma);
if max(df_row,df_col)>1
    error('Number of degrees of freedom must be a scalar');
end
[hp_row,hp_col]=size(hp);
if min(hp_row,hp_col)>1
    error('Holding period must be a vector');
end
[cl_row,cl_col]=size(cl);
if min(cl_row,cl_col)>1
    error('Confidence leve must be a scalar ');
end
% 
% To check that hp is read as a row vector as required
%
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
%
% Check that inputs obey sign and value restrictions
%
if sigma<0
    error('Standard deviation must be non-negative');
end
if df<3
    error('Number of degrees of freedom must be at least 3 for first two moments of distribution to be defined.');
end
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level must be greater than 0');
end
if min(hp)<=0
    error('Holding period(s) must be greater than 0');
end
%
% VaR estimation
%
var=-sigma*sqrt(hp')*sqrt((df-2)/df)*tinv((1-cl),df)-mu*hp'*ones(size(cl)); %t-VaR 
%
% ES estimation
%
n=1000;                                           % Number of slices into which tail is divided 
cl0=cl;                                              % Initial confidence level
w=var;                                                
delta_cl=(1-cl)/n;                            % Increment to confidence level as each slice is taken
for i=1:n-1
cl=cl0+i*delta_cl;                            % Revised cl
w=w-sigma*sqrt(hp')*sqrt((df-2)/df)*tinv((1-cl),df)-mu*hp'*ones(size(cl));
end;
es=w/n;
plot(hp,es);
axis;
cl_label=100*cl0;
%
% Input data labels
%
text(min(hp)+.1*(max(hp)-min(hp)),max(es)-.1*(max(es)-min(es)),'Input parameters','Fontweight','bold')
text(min(hp)+.1*(max(hp)-min(hp)),max(es)-.2*(max(es)-min(es)),['Daily mean L/P = ',num2str(-mu)])
text(min(hp)+.1*(max(hp)-min(hp)),max(es)-.3*(max(es)-min(es)),['St. dev. of daily L/P = ',num2str(sigma)])
text(min(hp)+.1*(max(hp)-min(hp)),max(es)-.4*(max(es)-min(es)),['Degrees of freedom  = ',num2str(df)])
text(min(hp)+.1*(max(hp)-min(hp)),max(es)-.5*(max(es)-min(es)),['Confidence level = ',num2str(cl_label),'%'])
%
% Axis labels
%
xlabel('Holding period','Fontweight','bold');
ylabel('ES','rotation',0,'horizontal','right','Fontweight','bold');
title('t ES against holding period','FontSize',12,'Fontweight','bold');


